@@ -32,13 +32,9 @@ impl Color {
   }
 
   pub(crate) fn auto() -> Self {
-    Self {
-      use_color: UseColor::Auto,
-      ..Self::default()
-    }
+    Self::default()
   }
 
-  #[cfg(test)]
   pub(crate) fn always() -> Self {
     Self {
       use_color: UseColor::Always,
@@ -69,10 +65,18 @@ impl Color {
     self.restyle(Style::new().fg(Blue))
   }
 
+  pub(crate) fn doc_backtick(self) -> Self {
+    self.restyle(Style::new().fg(Cyan))
+  }
+
   pub(crate) fn error(self) -> Self {
     self.restyle(Style::new().fg(Red).bold())
   }
 
+  pub(crate) fn group(self) -> Self {
+    self.restyle(Style::new().fg(Yellow).bold())
+  }
+
   pub(crate) fn warning(self) -> Self {
     self.restyle(Style::new().fg(Yellow).bold())
   }
