@@ -2,14 +2,6 @@ use super::*;
 
 #[derive(Debug, PartialEq)]
 pub(crate) enum CompileErrorKind<'src> {
-  AliasInvalidAttribute {
-    alias: &'src str,
-    attribute: Attribute<'src>,
-  },
-  AliasShadowsRecipe {
-    alias: &'src str,
-    recipe_line: usize,
-  },
   AttributeArgumentCountMismatch {
     attribute: &'src str,
     found: usize,
@@ -63,10 +55,13 @@ pub(crate) enum CompileErrorKind<'src> {
     variable: &'src str,
   },
   ExtraLeadingWhitespace,
+  ExtraneousAttributes {
+    count: usize,
+  },
   FunctionArgumentCountMismatch {
     function: &'src str,
     found: usize,
-    expected: Range<usize>,
+    expected: RangeInclusive<usize>,
   },
   Include,
   InconsistentLeadingWhitespace {
@@ -76,6 +71,11 @@ pub(crate) enum CompileErrorKind<'src> {
   Internal {
     message: String,
   },
+  InvalidAttribute {
+    item_kind: &'static str,
+    item_name: &'src str,
+    attribute: Attribute<'src>,
+  },
   InvalidEscapeSequence {
     character: char,
   },
@@ -87,6 +87,9 @@ pub(crate) enum CompileErrorKind<'src> {
   MixedLeadingWhitespace {
     whitespace: &'src str,
   },
+  NoCdAndWorkingDirectoryAttribute {
+    recipe: &'src str,
+  },
   ParameterFollowsVariadicParameter {
     parameter: &'src str,
   },
@@ -94,6 +97,9 @@ pub(crate) enum CompileErrorKind<'src> {
   RequiredParameterFollowsDefaultParameter {
     parameter: &'src str,
   },
+  ShebangAndScriptAttribute {
+    recipe: &'src str,
+  },
   ShellExpansion {
     err: shellexpand::LookupError<env::VarError>,
   },
@@ -113,6 +119,20 @@ pub(crate) enum CompileErrorKind<'src> {
     expected: Vec<TokenKind>,
     found: TokenKind,
   },
+  UnicodeEscapeCharacter {
+    character: char,
+  },
+  UnicodeEscapeDelimiter {
+    character: char,
+  },
+  UnicodeEscapeEmpty,
+  UnicodeEscapeLength {
+    hex: String,
+  },
+  UnicodeEscapeRange {
+    hex: String,
+  },
+  UnicodeEscapeUnterminated,
   UnknownAliasTarget {
     alias: &'src str,
     target: &'src str,
