@@ -1,4 +1,4 @@
-use {super::*, clap::ValueEnum};
+use super::*;
 
 #[derive(ValueEnum, Debug, Clone, Copy, PartialEq)]
 pub(crate) enum Shell {
@@ -141,18 +141,18 @@ const ZSH_COMPLETION_REPLACEMENTS: &[(&str, &str)] = &[
     r"    local common=(",
   ),
   (
-    r"'*--set=[Override <VARIABLE> with <VALUE>]:VARIABLE: :VARIABLE: ' \",
+    r"'*--set=[Override <VARIABLE> with <VALUE>]:VARIABLE:_default:VARIABLE:_default' \",
     r"'*--set=[Override <VARIABLE> with <VALUE>]: :(_just_variables)' \",
   ),
   (
-    r"'()-s+[Show recipe at <PATH>]:PATH: ' \
-'()--show=[Show recipe at <PATH>]:PATH: ' \",
+    r"'()-s+[Show recipe at <PATH>]:PATH:_default' \
+'()--show=[Show recipe at <PATH>]:PATH:_default' \",
     r"'-s+[Show recipe at <PATH>]: :(_just_commands)' \
 '--show=[Show recipe at <PATH>]: :(_just_commands)' \",
   ),
   (
     "'*::ARGUMENTS -- Overrides and recipe(s) to run, defaulting to the first recipe in the \
-     justfile:' \\
+     justfile:_default' \\
 && ret=0",
     r#")
 
@@ -255,7 +255,7 @@ const POWERSHELL_COMPLETION_REPLACEMENTS: &[(&str, &str)] = &[(
   r#"function Get-JustFileRecipes([string[]]$CommandElements) {
         $justFileIndex = $commandElements.IndexOf("--justfile");
 
-        if ($justFileIndex -ne -1 && $justFileIndex + 1 -le $commandElements.Length) {
+        if ($justFileIndex -ne -1 -and $justFileIndex + 1 -le $commandElements.Length) {
             $justFileLocation = $commandElements[$justFileIndex + 1]
         }
 
