@@ -1,7 +1,10 @@
 use {
   super::*,
   clap::{
-    builder::{styling::AnsiColor, FalseyValueParser, Styles},
+    builder::{
+      styling::{AnsiColor, Effects},
+      FalseyValueParser, Styles,
+    },
     parser::ValuesRef,
     value_parser, Arg, ArgAction, ArgGroup, ArgMatches, Command,
   },
@@ -9,6 +12,7 @@ use {
 
 #[derive(Debug, PartialEq)]
 pub(crate) struct Config {
+  pub(crate) allow_missing: bool,
   pub(crate) check: bool,
   pub(crate) color: Color,
   pub(crate) command_color: Option<ansi_term::Color>,
@@ -16,6 +20,7 @@ pub(crate) struct Config {
   pub(crate) dotenv_path: Option<PathBuf>,
   pub(crate) dry_run: bool,
   pub(crate) dump_format: DumpFormat,
+  pub(crate) explain: bool,
   pub(crate) highlight: bool,
   pub(crate) invocation_directory: PathBuf,
   pub(crate) list_heading: String,
@@ -24,6 +29,7 @@ pub(crate) struct Config {
   pub(crate) load_dotenv: bool,
   pub(crate) no_aliases: bool,
   pub(crate) no_dependencies: bool,
+  pub(crate) one: bool,
   pub(crate) search_config: SearchConfig,
   pub(crate) shell: Option<String>,
   pub(crate) shell_args: Option<Vec<String>>,
@@ -50,6 +56,7 @@ mod cmd {
   pub(crate) const INIT: &str = "INIT";
   pub(crate) const LIST: &str = "LIST";
   pub(crate) const MAN: &str = "MAN";
+  pub(crate) const REQUEST: &str = "REQUEST";
   pub(crate) const SHOW: &str = "SHOW";
   pub(crate) const SUMMARY: &str = "SUMMARY";
   pub(crate) const VARIABLES: &str = "VARIABLES";
@@ -66,6 +73,7 @@ mod cmd {
     INIT,
     LIST,
     MAN,
+    REQUEST,
     SHOW,
     SUMMARY,
     VARIABLES,
@@ -73,9 +81,12 @@ mod cmd {
 
   pub(crate) const ARGLESS: &[&str] =
     &[CHANGELOG, DUMP, EDIT, FORMAT, INIT, MAN, SUMMARY, VARIABLES];
+
+  pub(crate) const HEADING: &str = "Commands";
 }
 
 mod arg {
+  pub(crate) const ALLOW_MISSING: &str = "ALLOW-MISSING";
   pub(crate) const ARGUMENTS: &str = "ARGUMENTS";
   pub(crate) const CHECK: &str = "CHECK";
   pub(crate) const CHOOSER: &str = "CHOOSER";
@@ -86,6 +97,7 @@ mod arg {
   pub(crate) const DOTENV_PATH: &str = "DOTENV-PATH";
   pub(crate) const DRY_RUN: &str = "DRY-RUN";
   pub(crate) const DUMP_FORMAT: &str = "DUMP-FORMAT";
+  pub(crate) const EXPLAIN: &str = "EXPLAIN";
   pub(crate) const GLOBAL_JUSTFILE: &str = "GLOBAL-JUSTFILE";
   pub(crate) const HIGHLIGHT: &str = "HIGHLIGHT";
   pub(crate) const JUSTFILE: &str = "JUSTFILE";
@@ -96,6 +108,7 @@ mod arg {
   pub(crate) const NO_DEPS: &str = "NO-DEPS";
   pub(crate) const NO_DOTENV: &str = "NO-DOTENV";
   pub(crate) const NO_HIGHLIGHT: &str = "NO-HIGHLIGHT";
+  pub(crate) const ONE: &str = "ONE";
   pub(crate) const QUIET: &str = "QUIET";
   pub(crate) const SET: &str = "SET";
   pub(crate) const SHELL: &str = "SHELL";
@@ -124,10 +137,13 @@ impl Config {
       .trailing_var_arg(true)
       .styles(
         Styles::styled()
-          .header(AnsiColor::Yellow.on_default())
+          .error(AnsiColor::Red.on_default() | Effects::BOLD)
+          .header(AnsiColor::Yellow.on_default() | Effects::BOLD)
+          .invalid(AnsiColor::Red.on_default())
           .literal(AnsiColor::Green.on_default())
-          .placeholder(AnsiColor::Green.on_default())
-          .usage(AnsiColor::Yellow.on_default()),
+          .placeholder(AnsiColor::Cyan.on_default())
+          .usage(AnsiColor::Yellow.on_default() | Effects::BOLD)
+          .valid(AnsiColor::Green.on_default()),
       )
       .arg(
         Arg::new(arg::CHECK)
@@ -204,6 +220,13 @@ impl Config {
           .value_name("FORMAT")
           .help("Dump justfile as <FORMAT>"),
       )
+      .arg(
+        Arg::new(arg::EXPLAIN)
+          .action(ArgAction::SetTrue)
+          .long("explain")
+          .env("JUST_EXPLAIN")
+          .help("Print recipe doc comment before running it"),
+      )
       .arg(
         Arg::new(arg::GLOBAL_JUSTFILE)
           .action(ArgAction::SetTrue)
@@ -286,6 +309,13 @@ impl Config {
           .help("Don't highlight echoed recipe lines in bold")
           .overrides_with(arg::HIGHLIGHT),
       )
+      .arg(
+        Arg::new(arg::ONE)
+          .long("one")
+          .env("JUST_ONE")
+          .action(ArgAction::SetTrue)
+          .help("Forbid multiple recipes from being invoked on the command line"),
+      )
       .arg(
         Arg::new(arg::QUIET)
           .short('q')
@@ -295,6 +325,13 @@ impl Config {
           .help("Suppress all output")
           .conflicts_with(arg::DRY_RUN),
       )
+      .arg(
+        Arg::new(arg::ALLOW_MISSING)
+          .long("allow-missing")
+          .env("JUST_ALLOW_MISSING")
+          .action(ArgAction::SetTrue)
+          .help("Ignore missing recipe and module errors"),
+      )
       .arg(
         Arg::new(arg::SET)
           .long("set")
@@ -384,7 +421,8 @@ impl Config {
         Arg::new(cmd::CHANGELOG)
           .long("changelog")
           .action(ArgAction::SetTrue)
-          .help("Print changelog"),
+          .help("Print changelog")
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::CHOOSE)
@@ -393,7 +431,8 @@ impl Config {
           .help(
             "Select one or more recipes to run using a binary chooser. If `--chooser` is not \
              passed the chooser defaults to the value of $JUST_CHOOSER, falling back to `fzf`",
-          ),
+          )
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::COMMAND)
@@ -406,7 +445,8 @@ impl Config {
           .help(
             "Run an arbitrary command with the working directory, `.env`, overrides, and exports \
              set",
-          ),
+          )
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::COMPLETIONS)
@@ -415,20 +455,23 @@ impl Config {
           .value_name("SHELL")
           .value_parser(value_parser!(completions::Shell))
           .ignore_case(true)
-          .help("Print shell completion script for <SHELL>"),
+          .help("Print shell completion script for <SHELL>")
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::DUMP)
           .long("dump")
           .action(ArgAction::SetTrue)
-          .help("Print justfile"),
+          .help("Print justfile")
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::EDIT)
           .short('e')
           .long("edit")
           .action(ArgAction::SetTrue)
-          .help("Edit justfile with editor given by $VISUAL or $EDITOR, falling back to `vim`"),
+          .help("Edit justfile with editor given by $VISUAL or $EDITOR, falling back to `vim`")
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::EVALUATE)
@@ -438,27 +481,31 @@ impl Config {
           .help(
             "Evaluate and print all variables. If a variable name is given as an argument, only \
              print that variable's value.",
-          ),
+          )
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::FORMAT)
           .long("fmt")
           .alias("format")
           .action(ArgAction::SetTrue)
-          .help("Format and overwrite justfile"),
+          .help("Format and overwrite justfile")
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::GROUPS)
           .long("groups")
           .action(ArgAction::SetTrue)
-          .help("List recipe groups"),
+          .help("List recipe groups")
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::INIT)
           .long("init")
           .alias("initialize")
           .action(ArgAction::SetTrue)
-          .help("Initialize new justfile in project root"),
+          .help("Initialize new justfile in project root")
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::LIST)
@@ -468,13 +515,26 @@ impl Config {
           .value_name("PATH")
           .action(ArgAction::Set)
           .conflicts_with(arg::ARGUMENTS)
-          .help("List available recipes"),
+          .help("List available recipes")
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::MAN)
           .long("man")
           .action(ArgAction::SetTrue)
-          .help("Print man page"),
+          .help("Print man page")
+          .help_heading(cmd::HEADING),
+      )
+      .arg(
+        Arg::new(cmd::REQUEST)
+          .long("request")
+          .action(ArgAction::Set)
+          .hide(true)
+          .help(
+            "Execute <REQUEST>. For internal testing purposes only. May be changed or removed at \
+            any time.",
+          )
+          .help_heading(cmd::REQUEST),
       )
       .arg(
         Arg::new(cmd::SHOW)
@@ -484,19 +544,22 @@ impl Config {
           .action(ArgAction::Set)
           .value_name("PATH")
           .conflicts_with(arg::ARGUMENTS)
-          .help("Show recipe at <PATH>"),
+          .help("Show recipe at <PATH>")
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::SUMMARY)
           .long("summary")
           .action(ArgAction::SetTrue)
-          .help("List names of available recipes"),
+          .help("List names of available recipes")
+          .help_heading(cmd::HEADING),
       )
       .arg(
         Arg::new(cmd::VARIABLES)
           .long("variables")
           .action(ArgAction::SetTrue)
-          .help("List names of variables"),
+          .help("List names of variables")
+          .help_heading(cmd::HEADING),
       )
       .group(ArgGroup::new("SUBCOMMAND").args(cmd::ALL))
       .arg(
@@ -652,6 +715,11 @@ impl Config {
       }
     } else if matches.get_flag(cmd::MAN) {
       Subcommand::Man
+    } else if let Some(request) = matches.get_one::<String>(cmd::REQUEST) {
+      Subcommand::Request {
+        request: serde_json::from_str(request)
+          .map_err(|source| ConfigError::RequestParse { source })?,
+      }
     } else if let Some(path) = matches.get_many::<String>(cmd::SHOW) {
       Subcommand::Show {
         path: Self::parse_module_path(path)?,
@@ -668,8 +736,10 @@ impl Config {
     };
 
     let unstable = matches.get_flag(arg::UNSTABLE) || subcommand == Subcommand::Summary;
+    let explain = matches.get_flag(arg::EXPLAIN);
 
     Ok(Self {
+      allow_missing: matches.get_flag(arg::ALLOW_MISSING),
       check: matches.get_flag(arg::CHECK),
       color: (*matches.get_one::<UseColor>(arg::COLOR).unwrap()).into(),
       command_color: matches
@@ -685,6 +755,7 @@ impl Config {
         .get_one::<DumpFormat>(arg::DUMP_FORMAT)
         .unwrap()
         .clone(),
+      explain,
       highlight: !matches.get_flag(arg::NO_HIGHLIGHT),
       invocation_directory: env::current_dir().context(config_error::CurrentDirContext)?,
       list_heading: matches.get_one::<String>(arg::LIST_HEADING).unwrap().into(),
@@ -693,6 +764,7 @@ impl Config {
       load_dotenv: !matches.get_flag(arg::NO_DOTENV),
       no_aliases: matches.get_flag(arg::NO_ALIASES),
       no_dependencies: matches.get_flag(arg::NO_DEPS),
+      one: matches.get_flag(arg::ONE),
       search_config,
       shell: matches.get_one::<String>(arg::SHELL).map(Into::into),
       shell_args: if matches.get_flag(arg::CLEAR_SHELL_ARGS) {
@@ -720,23 +792,17 @@ impl Config {
     })
   }
 
-  pub(crate) fn require_unstable(&self, message: &str) -> RunResult<'static> {
-    if self.unstable {
+  pub(crate) fn require_unstable(
+    &self,
+    justfile: &Justfile,
+    unstable_feature: UnstableFeature,
+  ) -> RunResult<'static> {
+    if self.unstable || justfile.settings.unstable {
       Ok(())
     } else {
-      Err(Error::Unstable {
-        message: message.to_owned(),
-      })
+      Err(Error::UnstableFeature { unstable_feature })
     }
   }
-
-  pub(crate) fn run(self, loader: &Loader) -> RunResult {
-    if let Err(error) = InterruptHandler::install(self.verbosity) {
-      warn!("Failed to set CTRL-C handler: {error}");
-    }
-
-    self.subcommand.execute(&self, loader)
-  }
 }
 
 #[cfg(test)]
