@@ -61,10 +61,10 @@ test! {
   stdout: "",
   stderr: "
     error: Variable `b` not defined
-     --> justfile:1:9
-      |
-    1 | a := if b == '' { '' } else { '' }
-      |         ^
+     ——▶ justfile:1:9
+      │
+    1 │ a := if b == '' { '' } else { '' }
+      │         ^
   ",
   status: EXIT_FAILURE,
 }
@@ -80,10 +80,10 @@ test! {
   stdout: "",
   stderr: "
     error: Variable `b` not defined
-     --> justfile:1:15
-      |
-    1 | a := if '' == b { '' } else { '' }
-      |               ^
+     ——▶ justfile:1:15
+      │
+    1 │ a := if '' == b { '' } else { '' }
+      │               ^
   ",
   status: EXIT_FAILURE,
 }
@@ -99,10 +99,10 @@ test! {
   stdout: "",
   stderr: "
     error: Variable `b` not defined
-     --> justfile:1:20
-      |
-    1 | a := if '' == '' { b } else { '' }
-      |                    ^
+     ——▶ justfile:1:20
+      │
+    1 │ a := if '' == '' { b } else { '' }
+      │                    ^
   ",
   status: EXIT_FAILURE,
 }
@@ -118,10 +118,10 @@ test! {
   stdout: "",
   stderr: "
     error: Variable `b` not defined
-     --> justfile:1:32
-      |
-    1 | a := if '' == '' { '' } else { b }
-      |                                ^
+     ——▶ justfile:1:32
+      │
+    1 │ a := if '' == '' { '' } else { b }
+      │                                ^
   ",
   status: EXIT_FAILURE,
 }
@@ -136,11 +136,11 @@ test! {
   ",
   stdout: "",
   stderr: "
-    error: Expected '!=', '==', '=~', '+', or '/', but found identifier
-     --> justfile:1:12
-      |
-    1 | a := if '' a '' { '' } else { b }
-      |            ^
+    error: Expected '&&', '!=', '||', '==', '=~', '+', or '/', but found identifier
+     ——▶ justfile:1:12
+      │
+    1 │ a := if '' a '' { '' } else { b }
+      │            ^
   ",
   status: EXIT_FAILURE,
 }
@@ -182,10 +182,10 @@ test! {
   stdout: "",
   stderr: "
     error: Expected keyword `else` but found `end of line`
-     --> justfile:1:54
-      |
-    1 | TEST := if path_exists('/bin/bash') == 'true' {'yes'}
-      |                                                      ^
+     ——▶ justfile:1:54
+      │
+    1 │ TEST := if path_exists('/bin/bash') == 'true' {'yes'}
+      │                                                      ^
   ",
   status: EXIT_FAILURE,
 }
@@ -198,10 +198,10 @@ test! {
   stdout: "",
   stderr: "
     error: Expected keyword `else` but found identifier `els`
-     --> justfile:1:55
-      |
-    1 | TEST := if path_exists('/bin/bash') == 'true' {'yes'} els {'no'}
-      |                                                       ^^^
+     ——▶ justfile:1:55
+      │
+    1 │ TEST := if path_exists('/bin/bash') == 'true' {'yes'} els {'no'}
+      │                                                       ^^^
   ",
   status: EXIT_FAILURE,
 }
