@@ -6,10 +6,11 @@ pub(crate) use {
     test::{assert_eval_eq, Output, Test},
   },
   executable_path::executable_path,
-  just::unindent,
+  just::{unindent, Response},
   libc::{EXIT_FAILURE, EXIT_SUCCESS},
   pretty_assertions::Comparison,
   regex::Regex,
+  serde::{Deserialize, Serialize},
   serde_json::{json, Value},
   std::{
     collections::BTreeMap,
@@ -28,11 +29,16 @@ pub(crate) use {
   which::which,
 };
 
+fn default<T: Default>() -> T {
+  Default::default()
+}
+
 #[macro_use]
 mod test;
 
 mod allow_duplicate_recipes;
 mod allow_duplicate_variables;
+mod allow_missing;
 mod assert_stdout;
 mod assert_success;
 mod assertions;
@@ -59,7 +65,7 @@ mod examples;
 mod explain;
 mod export;
 mod fallback;
-mod fmt;
+mod format;
 mod functions;
 #[cfg(unix)]
 mod global;
@@ -93,6 +99,7 @@ mod quote;
 mod readme;
 mod recursion_limit;
 mod regexes;
+mod request;
 mod run;
 mod script;
 mod search;
